@@ -24,7 +24,6 @@
 #include <gtkmm/spinbutton.h>
 #include <gtkmm/entry.h>
 #include <gtkmm/colorbutton.h>
-#include "defaultdialog.hpp"
 #include "colorsel.hpp"
 #include "config.hpp"
 #include "fileentry.hpp"
@@ -32,10 +31,10 @@
 namespace Gobby
 {
 
-class HostDialog : public DefaultDialog
+class HostDialog: public Gtk::Dialog
 {
 public:
-	HostDialog(Gtk::Window& parent, Config& config);
+	HostDialog(Gtk::Window& parent, Config::ParentEntry& config_entry);
 	virtual ~HostDialog();
 
 	unsigned int get_port() const;
@@ -53,7 +52,7 @@ public:
 protected:
 	virtual void on_response(int response_id);
 
-	Config& m_config;
+	Config::ParentEntry& m_config_entry;
 
 	Gtk::Table m_table;
 	Gtk::Label m_lbl_port;
