@@ -38,6 +38,7 @@ namespace {
 		"      <menuitem action=\"AppSessionCreate\" />"
 		"      <menuitem action=\"AppSessionJoin\" />"
 		"      <menuitem action=\"AppSessionSave\" />"
+		"      <menuitem action=\"AppSessionSaveAs\" />"
 		"      <menuitem action=\"AppSessionQuit\" />"
 		"      <separator />"
 		"      <menuitem action=\"AppQuit\" />"
@@ -47,6 +48,7 @@ namespace {
 		"      <menuitem action=\"SessionDocumentOpen\" />"
 		"      <menuitem action=\"SessionDocumentSave\" />"
 		"      <menuitem action=\"SessionDocumentSaveAs\" />"
+		"      <menuitem action=\"SessionDocumentSaveAll\" />"
 		"      <menuitem action=\"SessionDocumentClose\" />"
 		"    </menu>"
 		"    <menu action=\"MenuEdit\">"
@@ -249,11 +251,20 @@ Gobby::Header::Header(const ApplicationState& state,
 		Gtk::Action::create(
 			"AppSessionSave",
 			Gtk::Stock::SAVE,
-			_("Save session..."),
+			_("Save session"),
 			_("Saves the complete session for a later restore")
 		)
 	),
 
+	action_app_session_save_as(
+		Gtk::Action::create(
+			"AppSessionSaveAs",
+			Gtk::Stock::SAVE_AS,
+			_("Save session as..."),
+			_("\"Saves as...\" the complete session for a later restore")
+		)
+	),
+
 	action_app_session_quit(
 		Gtk::Action::create(
 			"AppSessionQuit",
@@ -310,6 +321,14 @@ Gobby::Header::Header(const ApplicationState& state,
 		)
 	),
 
+	action_session_document_save_all(
+		Gtk::Action::create(
+			"SessionDocumentSaveAll",
+			_("Save all documents"),
+			_("Saves all documents")
+		)
+	),
+
 	action_session_document_close(
 		Gtk::Action::create(
 			"SessionDocumentClose",
@@ -353,7 +372,7 @@ Gobby::Header::Header(const ApplicationState& state,
 			"EditPreferences",
 			Gtk::Stock::PREFERENCES,
 			_("Preferences..."),
-			_("Displays a dialog to customise Gobby for your needs")
+			_("Displays a dialog to customize Gobby for your needs")
 		)
 	),
 
@@ -384,8 +403,8 @@ Gobby::Header::Header(const ApplicationState& state,
 		Gtk::Action::create(
 			"UserSetColour",
 			Gtk::Stock::SELECT_COLOR,
-			_("Set colour..."),
-			_("Sets a new colour for this user")
+			_("Set color..."),
+			_("Sets a new color for this user")
 		)
 	),
 
@@ -454,6 +473,11 @@ Gobby::Header::Header(const ApplicationState& state,
 		APPLICATION_NONE, APPLICATION_INITIAL
 	);
 
+	set_action_auto(
+		action_app_session_save_as, state,
+		APPLICATION_NONE, APPLICATION_INITIAL
+	);
+
 	set_action_auto(
 		action_app_session_quit, state,
 		APPLICATION_SESSION, APPLICATION_NONE
@@ -489,6 +513,11 @@ Gobby::Header::Header(const ApplicationState& state,
 		APPLICATION_DOCUMENT, APPLICATION_NONE
 	);
 
+	set_action_auto(
+		action_session_document_save_all, state,
+		APPLICATION_DOCUMENT, APPLICATION_NONE
+	);
+
 	set_action_auto(
 		action_session_document_close, state,
 		APPLICATION_DOCUMENT, APPLICATION_NONE
@@ -580,7 +609,9 @@ Gobby::Header::Header(const ApplicationState& state,
 	group_app->add(action_app);
 	group_app->add(action_app_session_create);
 	group_app->add(action_app_session_join);
-	group_app->add(action_app_session_save, Gtk::AccelKey("") );
+	group_app->add(action_app_session_save,
+		Gtk::AccelKey("<control>E", "<Actions>/MenuApp/AppSessionSave") );
+	group_app->add(action_app_session_save_as);
 	group_app->add(action_app_session_quit);
 	group_app->add(action_app_quit);
 
@@ -589,6 +620,7 @@ Gobby::Header::Header(const ApplicationState& state,
 	group_session->add(action_session_document_open);
 	group_session->add(action_session_document_save);
 	group_session->add(action_session_document_save_as);
+	group_session->add(action_session_document_save_all);
 	group_session->add(action_session_document_close);
 
 	group_edit->add(action_edit);
